@@ -1,7 +1,7 @@
 import os
 import pandas as pd
 from abstract_utilities import *
-from .general_functions import make_type,convert_column,return_float_or_int,safe_get,get_number
+from .general_functions import split_and_clean_lines,make_type,convert_column,return_float_or_int,safe_get,get_number
 import geopandas as gpd
 from openpyxl import load_workbook, utils
 from difflib import get_close_matches
@@ -119,11 +119,19 @@ def get_df(source=None, nrows=None, skiprows=None, condition=None, indices=None)
                 df = pd.read_json(source, nrows=nrows)
             elif file_ext == '.parquet':
                 df = pd.read_parquet(source, nrows=nrows)
-            elif file_ext in ['.shp', '.cpg', '.dbf', '.shx', '.prj','.geojson']:
+            elif file_ext in ['.shp', '.cpg', '.dbf', '.shx','.geojson']:
                 df = gpd.read_file(source,driver=source_ext(file_ext))
+            elif file_ext in ['.prj']:
+                df = read_from_file(source)
+                return df
             else:
-                raise ValueError(f"Unsupported file extension: {file_ext}")
-            return filter_df(df, nrows=nrows, condition=condition, indices=indices)
+                try:
+                    df = read_from_file(source)
+                except:                
+                    raise logging.info(f"Unsupported file extension: {file_ext}")
+            if not isinstance(df, (dict, list,FileStorage)):
+                return filter_df(df, nrows=nrows, condition=condition, indices=indices)
+            source = df
         except Exception as e:
             logging.error(f"Failed to read file: {e}")
             return None
@@ -365,7 +373,7 @@ def count_rows_columns(df):
     rows, columns = df.shape  # df.shape returns a tuple (number of rows, number of columns)
     return rows, columns
 def get_min_max_from_query(query):
-    query = [return_float_or_int(obj) for obj in query if is_number(obj)]
+    query = [return_float_or_int(obj) for obj in make_list(query) if is_number(obj)]
     query.sort()
     minimum = get_number(safe_get(query,0))
     maximum = get_number(safe_get(query,-1))
@@ -376,7 +384,34 @@ def is_inverse(series,inverse=False):
     if inverse:
         series = ~series
     return series
-async def get_range(df, column, val):
+def get_geo_location_master():
+    return "/home/catalystRepository/distance_repository/filters/geo_location/zip_codes/sacramento_to_zipcodes_geo_locations.xlsx"
+def get_geo_location_master_headers():
+    return """COUNTY	COUNTY_closest_latitude	COUNTY_closest_longitude	ZIP	ZIP_closest_latitude	ZIP_closest_longitude	ZIP_COUNTY_closest_distance(mi)	ZIP_furthest_latitude	ZIP_furthest_longitude	ZIP_COUNTY_furthest_distance(mi)""".split('\t')
+async def distance_within_range(distance,geo_location_refference=None):
+    geo_location_refference = geo_location_refference or get_geo_location_master()
+    # Ensure distance is a float
+    distance = float(get_number(safe_get(distance, 0)))
+    
+    # Load geo location data
+    df_geo_location = get_df(geo_location_refference)
+    
+    # Convert ZIP codes to integers, assuming all entries are valid zip codes
+    df_geo_location['ZIP'] = df_geo_location['ZIP'].astype(str)
+    
+    # Convert distances to floats
+    df_geo_location['ZIP_COUNTY_furthest_distance(mi)'] = df_geo_location['ZIP_COUNTY_furthest_distance(mi)'].astype(float)
+    df_geo_location['ZIP_COUNTY_closest_distance(mi)'] = df_geo_location['ZIP_COUNTY_closest_distance(mi)'].astype(float)
+    
+    # Create a mask where the distance is within the specified range
+    mask = (distance >= df_geo_location['ZIP_COUNTY_closest_distance(mi)']) | (distance >= df_geo_location['ZIP_COUNTY_furthest_distance(mi)'])
+    
+    # Filter zip codes based on the mask
+    good_zips = df_geo_location.loc[mask, 'ZIP'].tolist()
+    
+    return good_zips
+
+async def get_range(df, column,query,inverseOption=False,caseOption=False,substringOption=False):
     """
     Filters the DataFrame based on numeric ranges specified in query.
     Optionally inverts the filter to exclude the specified range.
@@ -387,19 +422,22 @@ async def get_range(df, column, val):
     :param invert: If True, the range is inverted (excludes the range specified)
     :return: Filtered DataFrame
     """
+    if not isinstance(query,list):
+        query = split_and_clean_lines(query)
     logging.info(f"get_range processing")
     temp_df = df.copy()
     logging.info(f"temp_df created with type {type(temp_df)}")
-    minimum,maximum = get_min_max_from_query(val['query'])
+    minimum,maximum = get_min_max_from_query(query)
     logging.info(f"minimum,maximum : {minimum},{maximum}")
     temp_df[column] = pd.to_numeric(temp_df[column], errors='coerce')  # Coerce errors in case of non-numeric data
     # Create a condition for values within the specified range
     condition = temp_df[column].between(minimum,maximum , inclusive='both')
     # Filter the original DataFrame using the condition from the temporary DataFrame
-    return condition
+    series = is_inverse(condition,inverse=inverseOption)
+    return df[series]
 
 
-async def filter_dataframe(df, column,val):
+async def filter_dataframe(df, column,query,caseOption=False,substringOption=False,inverseOption=False):
     """
     Filters a DataFrame based on a comparison between a column's values and a list.
 
@@ -413,17 +451,39 @@ async def filter_dataframe(df, column,val):
     Returns:
     - filtered_df: DataFrame containing only the rows that meet the condition.
     """
+    if not isinstance(query,list):
+        query = split_and_clean_lines(query)
+    compare_list=make_list(query)
     logging.info(f"filter_dataframe processing")
-    if not val['caseOption']:
-        compare_list = [str(item).lower() for item in val['query']]
+    if not caseOption:
+        compare_list = [str(item).lower() for item in compare_list]
         df[column] = df[column].astype(str).str.lower()
 
-    if val['substringOption']:
+    if substringOption:
         condition = df[column].apply(lambda x: any(str(item) in str(x) for item in compare_list))
     else:
         condition = df[column].apply(lambda x: any(str(item) == str(x) for item in compare_list))
-    
-    return condition
+    series = is_inverse(condition,inverse=inverseOption)
+    return df[series]
+async def filter_excel(df,column,query,range_option=False,caseOption=False,substringOption=False,inverseOption=False,distanceOption=False,geo_location_refference=None):
+    logging.info(f"recieved excel: parsing for column={column},range_option={range_option},caseOption={caseOption},substringOption={substringOption},inverseOption={inverseOption},distanceOption={distanceOption},geo_location_refference={geo_location_refference}")
+    df = get_df(df)
+    logging.info(f"query came as {query}")
+    if not isinstance(query,list):
+        query = split_and_clean_lines(query)
+    query=make_list(query)
+    logging.info(f"query started as  as {query}")
+    if distanceOption:
+        logging.info(f"distanceOption selected")
+        column=column or 'ZIP'
+        query = await distance_within_range(distance=query,geo_location_refference=geo_location_refference)
+        logging.info(f"query is now  as {query}")
+    if range_option:
+        logging.info(f"rangeOption selected")
+        df = await get_range(df,column,query,inverseOption=inverseOption,caseOption=caseOption,substringOption=substringOption)
+    else:
+        df = await filter_dataframe(df,column,query,caseOption=caseOption,substringOption=substringOption,inverseOption=inverseOption)
+    return df
 def update_excel(df,header,query):
     df = get_df(df)
     query = make_type(query,[str])
